@@ -1,13 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""
-__title__ = 'x'
-__author__ = 'JieYuan'
-__mtime__ = '18-12-14'
-"""
 
 import functools
 
+
 class xx:
     """I am very like a linux pipe"""
 
